---
name: Feature request
about: Can you please support...?
title: ''
labels: ''
assignees: ''

---

## I want to suggest a new step
### Which tool is this about? Where is its repository?
### Which operating systems are supported by this tool?
### What should Topgrade do to figure out if the tool needs to be invoked?
### Which exact commands should Topgrade run?

## I want to suggest some general feature
Topgrade should...

## More information
<!-- Assuming that someone else implements the feature,
please state if you know how to test it from a side branch of Topgrade. -->
